summaryrefslogtreecommitdiff
path: root/recipes-bsp/u-boot/files/fw_unlock_mmc.sh
diff options
context:
space:
mode:
authorMarcel Ziswiler <marcel.ziswiler@toradex.com>2015-10-30 10:40:16 +0100
committerMarcel Ziswiler <marcel.ziswiler@toradex.com>2015-10-30 10:40:16 +0100
commit19d6bba4d745191e910869385d1236cbaa03da83 (patch)
tree800953f5d27ffa4abbdc472be824f88ad1040c5d /recipes-bsp/u-boot/files/fw_unlock_mmc.sh
parent0b9d7b538d495fecaadda15f6f0902fe7c2bb5e1 (diff)
apalis/colibri_imx6/t30: u-boot-fw-utils: update fw_printenv/setenv
Introduce/update postinst code to dynamically adjust fw_env.config and fw_unlock_mmc.sh shell profile extension script to cope with our new unified eMMC layout: boot area partition 1 aka primary eMMC boot sector: with U-Boot boot loader and the U-Boot environment before the configblock at the end of that boot area partition
Diffstat (limited to 'recipes-bsp/u-boot/files/fw_unlock_mmc.sh')
-rw-r--r--recipes-bsp/u-boot/files/fw_unlock_mmc.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/recipes-bsp/u-boot/files/fw_unlock_mmc.sh b/recipes-bsp/u-boot/files/fw_unlock_mmc.sh
index 8982640..f9f253b 100644
--- a/recipes-bsp/u-boot/files/fw_unlock_mmc.sh
+++ b/recipes-bsp/u-boot/files/fw_unlock_mmc.sh
@@ -1,6 +1,6 @@
# Give fw_setenv mmcblk0boot1 write permissions
function fw_setenv() {
- echo 0 > /sys/block/mmcblk0boot1/force_ro
+ echo 0 > /sys/block/mmcblk0boot0/force_ro
/sbin/fw_setenv "$@"
- echo 1 > /sys/block/mmcblk0boot1/force_ro
+ echo 1 > /sys/block/mmcblk0boot0/force_ro
}
@@ -1,6 +1,6 @@
-# Give fw_setenv mmcblk0boot1 write permissions
+# Give fw_setenv mmcblk0boot0 write permissions
function fw_setenv() {